"""Prompt learning client facade."""

from __future__ import annotations

from synth_ai.sdk.optimization.internal.learning.prompt_learning_client import (  # noqa: F401
    PromptLearningClient,
)

__all__ = ["PromptLearningClient"]
