"""Graph optimization client facade."""

from __future__ import annotations

from synth_ai.sdk.optimization.internal.graph_optimization_client import (  # noqa: F401
    GraphOptimizationClient,
)

__all__ = ["GraphOptimizationClient"]
