"""Internal implementation modules for optimization.

This is an internal package - do not import from here directly.
Use `synth_ai.sdk.optimization` instead.
"""

# No public exports
__all__: list[str] = []
